# Generated file
# - do not overwrite
# - do not include in git
from collections import namedtuple

BuildInfo = namedtuple(
    'BuildInfo',
    ['version', 'built_at', 'sha', 'branch', 'tag'],
)

BUILD_INFO = BuildInfo(
    version='v4.18.4~067fdd9',
    built_at='2025-06-06 15:42:04Z',
    sha='067fdd935c760f9d9d2cdfc4e671e674f3a0de52',
    branch='HEAD',
    tag='v4.18.4',
)
